# scim2-tester

Python methods based on [scim2-models](https://scim2-models.readthedocs.io/en/latest/tutorial.html) and [scim2-client](https://scim2-client.readthedocs.io/en/latest/tutorial.html), to check if SCIM servers respect the [RFC7643](https://datatracker.ietf.org/doc/html/rfc7643.html) and [RFC7644](https://datatracker.ietf.org/doc/html/rfc7644.html) specifications.

It aims to be used in Continuous Integration suites and in healthcheck tools.

If you are seeking a CLI integration of scim2-tester, take a look at [scim2-cli](https://scim2-cli.readthedocs.io/en/latest/tutorial.html).

## Installation

```shell
pip install scim2-tester
```
